@@ -9,7 +9,8 @@ the use case is correct.
 #include <stdio.h>
 #include "cem.h"
 #include <glib.h>
-
+#include <sys/timeb.h>
+#include <string.h>
 
 #include "../configure.h"
 
@@ -38,21 +39,23 @@ static gchar* type_to_word(int type) {
 GString* string = g_string_new("");
 
 if (type & J_LOG_DEBUG)
-	string = g_string_append(string,"DEBUG ");
+	string = g_string_append(string,"DEBUG         ");
 if (type & J_LOG_INFO)
-	string = g_string_append(string,"INFO ");
+	string = g_string_append(string,"INFO          ");
 if (type & J_LOG_FATAL)
-	string = g_string_append(string,"FATAL ");
+	string = g_string_append(string,"FATAL         ");
 if (type & J_LOG_ERROR)
-	string = g_string_append(string,"ERROR ");
+	string = g_string_append(string,"ERROR         ");
 if (type & J_LOG_WARN)
-	string = g_string_append(string,"WARN ");
+	string = g_string_append(string,"WARN          ");
 if (type & J_LOG_USER_ACTION)
-	string = g_string_append(string,"USER ");
+	string = g_string_append(string,"USER          ");
 if (type & J_LOG_NETWORK)
-	string = g_string_append(string,"NETWORK ");
+	string = g_string_append(string,"NETWORK       ");
 if (type & J_LOG_NETWORK_DEBUG)
 	string = g_string_append(string,"NETWORK_DEBUG ");
+if (type & J_LOG_MENTOR_SPEECH)
+	string = g_string_append(string,"MENTOR_SPEECH ");
 
 return g_string_free (string, FALSE);
 }
@@ -66,6 +69,34 @@ void cem_get_time(char timestamp_now[]) {
 	strftime (timestamp_now,80,"%Y.%m.%d_%H.%M.%S",timeinfo);
 }
 
+
+/*SMPTE
+[HH:MM:SS:FF],FF is frames at 25fps
+*/
+static void cem_get_SMPTE_time(char timestamp_now[]) {
+	time_t rawtime;
+	struct tm * timeinfo;
+	time ( &rawtime );
+	timeinfo = localtime ( &rawtime );
+
+	struct timeb tp;
+	ftime(&tp);
+	//printf("time = %ld.%d\n",tp.time,tp.millitm);
+
+	strftime (timestamp_now,80,"%H:%M:%S:",timeinfo);
+	int millis = tp.millitm;
+
+	//25fps -> we want value between 0...24
+	//1000/25=40
+	int fps = millis / 40;
+
+	//timestamp_now contains "HH:MM:SS:" so we want write at index 9.
+	if (fps<10)
+		snprintf(&timestamp_now[9], 3, "0%d", fps);
+	else
+		snprintf(&timestamp_now[9], 3, "%d", fps);
+}
+
 /*
 No need to add linebreaks.
 Usage:
@@ -99,7 +130,10 @@ void cem_add_to_log(char *message,int type){
 
 	if (type & log_level) { //We are interested in this type of log-message
 		name=type_to_word(type);
-		gchar* final = g_strdup_printf("*%s %s: '%s' :%s*\n",timestamp, name,message,name);
+		char SMPTE_timestamp [12];
+		cem_get_SMPTE_time(SMPTE_timestamp);
+
+		gchar* final = g_strdup_printf("[%s] %s: \"%s\"\n",SMPTE_timestamp, name,message);
 
 		if (log_file) {
 			fprintf(log_file,"%s",final);
