@@ -8,7 +8,9 @@
 #include "../../cem/cem.h"
 
 #include "theme.h"
+#include "../save_helper.h"
 
+static void load_this_sample_array_to_this_track_view_legacy1(JsonNode *sub_node,JammoEditingTrackView* track_view,jammo_theme* theme, gchar* theme_name, int variation);
 
 gboolean composition_game_file_helper_load_from_file(jammo_theme* theme, gpointer data,JammoEditingTrackView* bottom_track_view ,JammoEditingTrackView* upper_track_view) {
 
@@ -46,7 +48,7 @@ g_assert (object != NULL);
 
 gchar* theme_name ="";
 gint variation =-1;
-
+gint format_version = 1; //jammo-0.7.7 and all before that is format_version=1
 	//string
 	/* //No need to read icon on this phase.
 	node = json_object_get_member (object, "icon");
@@ -70,6 +72,15 @@ gint variation =-1;
 		//printf("variation: '%d'\n",variation);
 	}
 
+	//int
+	node = json_object_get_member (object, "format-version");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
+		format_version = json_node_get_int (node);
+	}
+	message = g_strdup_printf("using format_version: %d\n",format_version);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
+
 	gint track_counter =1;
 	//Array
 	node = json_object_get_member (object, "tracks");
@@ -112,47 +123,12 @@ gint variation =-1;
 				}
 			*/
 
-			//Array
 			sub_node = json_object_get_member (sub_object, "samples");
-			if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_ARRAY){
-				JsonArray* sample_array =  json_node_get_array (sub_node);
+			if (format_version==1) //Legacy1
+				load_this_sample_array_to_this_track_view_legacy1(sub_node,track_view,theme,theme_name,variation); //static
+			else
+				load_this_sample_array_to_this_track_view(sub_node,track_view,FALSE); //FALSE=non-reactive
 
-				guint length = json_array_get_length(sample_array);
-				//printf("length %d\n",length);
-				int i;
-				for (i=0;i<length;i++) {
-					JsonNode* sample_node;
-					sample_node = json_array_get_element(sample_array,i);
-					if (sample_node!=NULL && JSON_NODE_TYPE(sample_node) == JSON_NODE_OBJECT){
-						JsonObject* sample_object = json_node_get_object(sample_node);
-						gint loop_id=-1;
-						gint slot=-1;
-
-						//int
-						sub_node = json_object_get_member (sample_object, "loop_id");
-						if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-							loop_id =  json_node_get_int (sub_node);
-							//printf("loop_id: '%d'\n",loop_id);
-						}
-						//int
-						sub_node = json_object_get_member (sample_object, "slot");
-						if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-							slot =  json_node_get_int (sub_node);
-							//printf("slot: '%d'\n",slot);
-						}
-						if (track_view) {
-							ClutterActor* sample_button = theme_give_sample_button_for_this_theme_and_variation_for_this_id(theme, theme_name,variation,loop_id);
-							if (sample_button) {
-								jammo_editing_track_view_add_jammo_sample_button(track_view,JAMMO_SAMPLE_BUTTON(sample_button),slot);
-								clutter_actor_set_reactive(sample_button,FALSE);
-							} //sample_button!=NULL check
-						} //track!=NULL check
-
-					} //This sample-object is ready
-
-				} //Foreach in sample-array ready
-
-			} //sample-array is ready
 
 		} //Track is ready
 		track_counter++;
@@ -162,3 +138,53 @@ g_object_unref(parser);
 
 return TRUE;
 }
+
+
+/*
+ * This is used loading format-version=1 compositions.
+ */
+static void load_this_sample_array_to_this_track_view_legacy1(JsonNode *sub_node,JammoEditingTrackView* track_view,jammo_theme* theme, gchar* theme_name, int variation) {
+	//Array  //sub_node = json_object_get_member (sub_object, "samples");
+	if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_ARRAY){
+		JsonArray* sample_array =  json_node_get_array (sub_node);
+
+		guint length = json_array_get_length(sample_array);
+		//printf("length %d\n",length);
+		int i;
+		for (i=0;i<length;i++) {
+			JsonNode* sample_node;
+			sample_node = json_array_get_element(sample_array,i);
+			if (sample_node!=NULL && JSON_NODE_TYPE(sample_node) == JSON_NODE_OBJECT){
+				JsonObject* sample_object = json_node_get_object(sample_node);
+				gint loop_id=-1;
+				gint slot=-1;
+
+				//int
+				sub_node = json_object_get_member (sample_object, "loop_id");
+				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+					loop_id =  json_node_get_int (sub_node);
+					//printf("loop_id: '%d'\n",loop_id);
+				}
+
+				//int
+				sub_node = json_object_get_member (sample_object, "slot");
+				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+					slot =  json_node_get_int (sub_node);
+					//printf("slot: '%d'\n",slot);
+				}
+				if (track_view) {
+					ClutterActor* sample_button=NULL;
+						sample_button = theme_give_sample_button_for_this_theme_and_variation_for_this_id(theme, theme_name,variation,loop_id);
+					if (sample_button) {
+						jammo_editing_track_view_add_jammo_sample_button(track_view,JAMMO_SAMPLE_BUTTON(sample_button),slot);
+						clutter_actor_set_reactive(sample_button,FALSE);
+					} //sample_button!=NULL check
+				} //track!=NULL check
+
+			} //This sample-object is ready
+
+		} //Foreach in sample-array ready
+
+	} //sample-array is ready
+
+}
