@@ -25,8 +25,7 @@
 #include "../jammo.h"
 
 #include "../../cem/cem.h"
-#include "gui.h"
-#include "chum.h" /*For SCREEN_*-macros */
+#include "chum.h"
 #include "file_helper.h"
 #include "song.h"
 static JammoSequencer* singinggame_sequencer = NULL; //used for stopping
@@ -62,7 +61,9 @@ ClutterActor* singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequen
 	int fd = open(filepath1,O_RDONLY);
 	if (fd == -1) //File not found
 		{
-		printf("file '%s' not found\n",filepath1);
+		gchar* message = g_strdup_printf("file '%s' not found",filepath1);
+		cem_add_to_log(message,J_LOG_WARN);
+		g_free(message);
 		ClutterColor transparency = { 0, 0, 0, 0 };
 		texture_image = clutter_rectangle_new_with_color(&transparency);
 		clutter_actor_set_size(texture_image, 60.0,60.0);
@@ -112,10 +113,8 @@ static void start_sequencer(JammoMentor* mentor, const gchar* speech, gboolean i
 }
 
 
-
-
 static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointer none) {
-	printf("Sequencer stopped_playback\n");
+	cem_add_to_log("Playback-Sequencer stopped",J_LOG_INFO);
 
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget"); //No drawing on stage anymore, use this.
@@ -131,8 +130,7 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 	//Saving to cupboard.
 	gchar* cmd;
 
-	printf("do saving\n");
-
+	cem_add_to_log("Do saving",J_LOG_DEBUG);
 	char timestamp_now [80];
 	cem_get_time(timestamp_now);
 
@@ -144,8 +142,11 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 	g_free(jammo_directory);
 
 	//printf("Executing: '%s'\n",cmd);
-	if (system(cmd)) 
-		printf("Error, can't call '%s'\n",cmd);
+	if (system(cmd)) {
+		gchar* message = g_strdup_printf("Can't call '%s' ", cmd);
+		cem_add_to_log(message, J_LOG_ERROR);
+		g_free(message);
+	}
 	g_free(cmd);
 
 	FILE *ofp;
@@ -170,12 +171,11 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 
 
 void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user_data) {
+	cem_add_to_log("Recording-Sequencer stopped",J_LOG_INFO);
 	ClutterActor* view;
 	
 	view = CLUTTER_ACTOR(user_data);
 
-	printf("Sequencer stopped_recording\n");
-
 	/*
 	#ifdef MELODIC_CONTOUR
 	clutter_actor_hide(contour_cursor);
@@ -199,7 +199,7 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 		g_free(filename);
 		filename = g_strdup_printf("%s/comping.ogg", (chum_get_current_song())->fullpath); //try without language postfix
 		}
-	printf("looking for file '%s' for comping_track\n",filename);
+	//printf("looking for file '%s' for comping_track\n",filename);
 
 	JammoBackingTrack* backing_track;  
 	backing_track = jammo_backing_track_new(filename);   //for comping track
@@ -212,14 +212,16 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 	gchar* jammo_directory=configure_get_jammo_directory();
 	loaded_filename =  g_strdup_printf("%s/last_recorded.wav",jammo_directory);
 	g_free(jammo_directory);
-	printf("looking for file '%s' for loaded_track\n",loaded_filename);	
+	//printf("looking for file '%s' for loaded_track\n",loaded_filename);
 
 
 	//Recorded file must be there and it must not be zero sized.
 	struct stat buf;
 	if (stat(loaded_filename, &buf) == -1)
 		{
-		printf("Recorded file '%s' doesn't found\n",loaded_filename);
+		gchar* message = g_strdup_printf("Recorded file '%s' doesn't found",loaded_filename);
+		cem_add_to_log(message, J_LOG_WARN);
+		g_free(message);
 		}
 	else
 		{
@@ -242,7 +244,6 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 	singinggame_add_cursor(&green, sequencer, view, TRUE);
 
 
-	chum_set_state_of_chum(SCREEN_PLAY_RECORDED);
 
 	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "welldone.spx singinggame_listen.spx", start_sequencer, sequencer);
 }
@@ -280,7 +281,7 @@ Regardless of initialization_needed: current language are checked, and non-suppo
 */
 
 void singinggame_start_songselection(){
-	printf("Singinggame_start_songselection\n");
+	cem_add_to_log("Singinggame_start_songselection", J_LOG_INFO);
 
 	ClutterActor* container = jammo_get_actor_by_id("songselection-all-songs");
 
@@ -298,7 +299,7 @@ void singinggame_start_songselection(){
 	ClutterActor* texture;
 	gchar *new_name = g_strdup_printf("%s/language_flag%s.png", DATA_DIR, selected_language); //name contains prefix _
 
-	printf("looking for '%s'\n",new_name);
+	//printf("looking for '%s'\n",new_name);
 	button = jammo_get_actor_by_id("songselection-language");
 	//Remove old texture
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), NULL);
@@ -469,7 +470,10 @@ static void mentor_say_what_is_selected(TangleActor *actor, ClutterActorBox *arg
 void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	ClutterActor* ct =CLUTTER_ACTOR(source);
 	const gchar* name = clutter_actor_get_name(ct);
-	printf("duetto clicked. get_name: '%s'\n",name);
+
+	gchar* message = g_strdup_printf("%s clicked",name);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
 
 	ClutterActor* view = jammo_get_actor_by_id("songselection-view");
 	TangleButton* tanglebutton = TANGLE_BUTTON(jammo_get_actor_by_id("songselection-singmode-button"));
@@ -500,7 +504,10 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 void singinggame_language_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	ClutterActor* ct =CLUTTER_ACTOR(source);
 	const gchar* name = clutter_actor_get_name(ct);
-	printf("Language clicked. get_name: '%s'\n",name);
+
+	gchar* message = g_strdup_printf("Language '%s' clicked",name);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
 
 	chum_set_selected_language(name);
 
