@@ -239,7 +239,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		if ((mainview = jammo_get_actor_by_id("main-views-widget"))){
 			//printf("Will add 'view' to 'mainview'\n");
 			clutter_container_add(CLUTTER_CONTAINER(mainview), view, NULL);
-			g_object_set(view, "transition-duration", 0,NULL);
+			//g_object_set(view, "transition-duration", 0,NULL); //there are no any more "transition-duration"
 			clutter_actor_show(view);
 			//printf("succesfully made new view and put it to mainview\n");
 		}
