@@ -78,7 +78,7 @@ static gboolean save_image_pressed(TangleButton *tanglebutton, gpointer data){
 	clutter_actor_hide(jammo_get_actor_by_id("saving_dialog_cancel")); //No canceling after image is selected.
 
 	const gchar* name_of_icon = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
-	gchar* message = g_strdup_printf("Selected '%s' for icon\n",name_of_icon);
+	gchar* message = g_strdup_printf("Selected '%s' for icon",name_of_icon);
 	cem_add_to_log(message,J_LOG_DEBUG);
 	g_free(message);
 
@@ -165,10 +165,10 @@ static int static_counter_for_id = 0;
 This function creates new jammo_sample_button from given parameters and put it to given parent ClutterActor.
 */
 static void create_samplebutton(gchar* themename, gchar* variation, gchar* imagefile, gchar* soundfile, gfloat x, gfloat y,jammo_theme* theme,TangleWidget* container_for_buttons,TangleWidget* parent){
-	gchar *full_image = g_strdup_printf("%s/themes/%s/%s/%s",DATA_DIR,themename,variation,imagefile);
+	gchar *full_image = g_strdup_printf("themes/%s/%s/%s",themename,variation,imagefile);
 	//printf("image file: '%s'\n",full_image);
 
-	gchar *full_sound = g_strdup_printf("%s/themes/%s/%s/%s",DATA_DIR,themename,variation,soundfile);
+	gchar *full_sound = g_strdup_printf("themes/%s/%s/%s",themename,variation,soundfile);
 	//printf("sound file: '%s'\n",full_sound);
 
 	ClutterActor* sample_button;
@@ -196,7 +196,12 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 	else {
 	//This is good place to do menu for selecting icon for saved composition
 	if (x_place_for_icon<500) { //if 500px is used do not add anymore icons
-		ClutterActor* icon_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(full_image, NULL));
+		gchar* filename_for_icon_texture;
+		filename_for_icon_texture = tangle_lookup_filename(full_image);
+
+		ClutterActor* icon_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(filename_for_icon_texture, NULL));
+		g_free(filename_for_icon_texture);
+
 		gchar* name_for_callback = g_strdup_printf("%s",full_image); //FIXME: this is not free'ed!
 		g_signal_connect (icon_button, "clicked", G_CALLBACK (save_image_pressed),theme);
 		clutter_actor_set_name(icon_button, name_for_callback);
