@@ -10,19 +10,27 @@ This file contains the functionality of discuss menu.
 #include <glib.h>
 #include <glib-object.h>
 
+#define MAX_THREADS 31
+
+typedef struct {
+	gchar title[35];
+	GList *messages;
+}thread_type;
+
 void start_discuss();
 gboolean addDiscussion(char* name, int num);
 gboolean addThread(char* name, int num);
-void clear(ClutterActor *param_list);
 ClutterActor *create_line(int y, int length, int size, ClutterContainer *cont);
-ClutterActor *create_title(int x, int y, int max, ClutterContainer *cont, ClutterColor color, const gchar *arg);
 gboolean discuss_change_to_discussion_view(TangleActor *actor, gpointer data);
 gboolean discuss_change_to_discussion_threads_view(TangleActor *actor, gpointer data);
-void getDatabaseElements();
-static void autoscroll_to_correct_pos(ClutterActor *list_);
-static void getDiscussion(ClutterActor *element);
-static void getThread(ClutterActor *element);
+void getAllTopics();
+void getAllThreads();
+void getAllMessages(gchar *id);
+void getDiscussion(ClutterActor *element);
+void getThread(ClutterActor *element);
 void start_discussionthreads();
-
+void start_addthread_view();
+void discuss_change_to_add_thread_view();
+void add_new_thread();
 
 #endif 
