@@ -9,6 +9,9 @@ This file contains the functionality of Help menu.
 
 #include <glib-object.h>
 
+#define MAX_QUESTIONS 15
+#define MAX_COMMENTS 15
+
 void start_helpdesk();
 void helpdesk_get_questions(void);
 
@@ -29,6 +32,7 @@ void helpdesk_submit_button_pressed(void);
 void helpdesk_show_question_view(void);
 void helpdesk_show_comment_view(void);
 void helpdesk_show_helpdesk_view(void);
+void helpdesk_show_addquestion_view(void);
 
 typedef struct {
 	char sender[20];
@@ -37,9 +41,9 @@ typedef struct {
 
 typedef struct {
 	char sender[20];
-	char title[50];
+	char title[100];
 	char desc[300];
-	comment_type comments[10];
+	comment_type comments[MAX_COMMENTS];
 }helpdesk_question_type;
 	
 
