@@ -14,10 +14,14 @@ This file contains the functionality of JamMo Songs menu.
 #include <meam/jammo-meam.h>
 #include <meam/jammo-backing-track.h>
 #include "single_thread.h"
+#include "src/configure.h"
+
 
 static void autoscroll_to_correct_pos(ClutterActor *listToScroll);
+static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data);
 static ClutterContainer *list = 0;
 static gint listItemHeight = 0;
+static gboolean isrecording_voice_comment = FALSE;
 gchar* recording_filename;
 JammoSequencer* sequencer;
 
@@ -47,12 +51,6 @@ void start_jammosongs(){
 		else
 			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosongs-songs-list-unscrollable"));	
 
-		clutter_actor_lower(jammo_get_actor_by_id("jammosongs-right-index"), jammo_get_actor_by_id("jammosongs-down-index"));
-				
-		clutter_actor_raise(jammo_get_actor_by_id("jammosongs-button-container"), jammo_get_actor_by_id("jammosongs-down-index"));
-		
-		clutter_actor_lower(CLUTTER_ACTOR(list), jammo_get_actor_by_id("jammosongs-down-index"));
-
 
 		for(int i = 0; i < numberOfSongs; i++){
 			add_song_to_list(NULL, i);	
@@ -126,19 +124,17 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs){
 		(clutter_texture_new_from_file("/opt/jammo/sequencer/label_audio.png", NULL));
 
 
-	clutter_actor_set_position(rec, 400, listItemHeight/3);
+	clutter_actor_set_position(rec, 660, listItemHeight/3);
+	clutter_actor_set_size(rec, 55, 28);
 	clutter_container_add_actor(listContainer, rec);	
 
-	ClutterActor *label = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL);
-
-	
-	ClutterActor *recLabel = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
+	ClutterActor *label = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
 
 	clutter_actor_set_position(label, 500, listItemHeight/3);
 	clutter_container_add_actor(listContainer, label);
 	
 
-	clutter_actor_set_position(CLUTTER_ACTOR(reviewButton), 690, 15);
+	clutter_actor_set_position(CLUTTER_ACTOR(reviewButton), 740, 15);
 
 	clutter_container_add_actor(listContainer, CLUTTER_ACTOR(reviewButton));
 	
@@ -151,7 +147,7 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs){
 	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_press_action), songName);			
 	g_signal_connect_swapped(video, "clicked", G_CALLBACK(show_music_video), songName);
 	g_signal_connect_swapped(label, "clicked", G_CALLBACK(show_song_label), songName);	
-	
+
 	clutter_container_add_actor(list, CLUTTER_ACTOR(listContainer));
 	
 	
@@ -172,17 +168,24 @@ void review_selected_song(ClutterActor *song){
 	GList *messages = NULL;
 	
 	//TODO: get messages to list
-	gchar *message;
+	message *msg;
 	int i;
+	time_t now;
 	
 	for(i = 0; i < 3 /*this should be the number of messages*/; i++){
-	
-		message = malloc(strlen("Message#1")+1);
-		sprintf(message, "Message#%d", i+1);
-		messages = g_list_append(messages, (gpointer)message);
+		msg = malloc(sizeof (message));
+		msg->msg = malloc(strlen("Message#1")+1);
+		sprintf(msg->msg, "Message#%d", i+1);
+		strcpy(msg->avatar, "x");
+		strcpy(msg->title, "");
+		strcpy(msg->sender, "Teppo");
+		strcpy(msg->time, "21.1.2011 10:09");
+
+		messages = g_list_append(messages, (gpointer)msg);
 	}
 
-
+	if(isrecording_voice_comment)
+		stop_recording();
 	
 	int first = 0;
 	
@@ -200,7 +203,7 @@ void review_selected_song(ClutterActor *song){
 				clear_container(list);	
 				ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 				clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
-				start_thread_view(messages);
+				start_thread_view(messages, "jammosongs", NULL);
 				
 				break;
 				}
@@ -217,6 +220,9 @@ void review_selected_song(ClutterActor *song){
 void end_jammosongs(TangleButton *tanglebutton, gpointer none){
 
 	clear_container(list);
+
+	if(isrecording_voice_comment)
+		stop_recording();
    
 	if(strcmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)), "gotocommunity") == 0)
 		startmenu_goto_communitymenu(tanglebutton, none);
@@ -255,17 +261,21 @@ void record_voice_comment(){
 	g_print("Recording...\n");
 	g_print("Max length is 30 seconds.\n");
 
+	isrecording_voice_comment = TRUE;
+
 	jammo_sequencer_play(JAMMO_SEQUENCER(sequencer));
 }
 
 void stop_recording()
 {
+	isrecording_voice_comment = FALSE;
 	jammo_sequencer_stop(JAMMO_SEQUENCER(sequencer));
 }
 
 static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data) 
 {
 	g_print("Stopped recording.\n");
+	isrecording_voice_comment = FALSE;
 }
 
 void rec_press_action(){
