@@ -40,11 +40,6 @@ void start_jammosounds(){
 		else
 			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosounds-songs-list-unscrollable"));	
 
-		clutter_actor_lower(jammo_get_actor_by_id("jammosounds-right-index"), jammo_get_actor_by_id("jammosounds-down-index"));
-;
-		clutter_actor_lower(CLUTTER_ACTOR(list), jammo_get_actor_by_id("jammosounds-down-index"));
-		
-		clutter_actor_raise(jammo_get_actor_by_id("jammosounds-button-container"),  jammo_get_actor_by_id("jammosounds-down-index"));
 
 		for(int i = 0; i < numberOfLoops; i++){
 			add_loop_to_list(NULL, i);	
@@ -125,7 +120,7 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	
 	
 	if(numberOfLoops <= 6)
-		clutter_actor_set_height(CLUTTER_ACTOR(list), listItemHeight * numberOfLoops);	
+		clutter_actor_set_height(CLUTTER_ACTOR(list), listItemHeight * numberOfLoops+1);	
 
 	else
 		clutter_actor_set_height(CLUTTER_ACTOR(list), listItemHeight * 6);		
@@ -159,7 +154,7 @@ void import_selected_loop(ClutterActor *loop){
 
 	GList *children = clutter_container_get_children(list);
 	int first = 0;
-	
+
 	if(children != NULL){
 		
 		do{
