@@ -4,6 +4,7 @@ License: GPLv2, read more from COPYING
 This file contains the functionality of JamMo Sounds menu.
  */
 
+
 #ifndef JAMMOSOUNDS_H_
 #define JAMMOSOUNDS_H_
 
@@ -11,9 +12,7 @@ This file contains the functionality of JamMo Sounds menu.
 void start_jammosounds();
 void end_jammosounds(TangleButton *tanglebutton, gpointer none);
 gboolean add_loop_to_list(char* loop_name, int number);
-static void autoscroll_to_correct_pos(ClutterActor *listToScroll);
-static void import_selected_loop(ClutterActor*);
-void clear_container(ClutterContainer *listToClear);
-void play_selected_loop(ClutterActor*);
+void import_selected_loop(ClutterActor*);
+
 
 #endif 
