@@ -9,6 +9,7 @@ This file contains the functionality of help menu.
 #include "startmenu.h"
 #include "../jammo.h"
 #include "mysongs.h"
+#include "community_utilities.h"
 
 static ClutterContainer *songlist = 0;
 static gint listItemHeight = 0;
@@ -38,10 +39,7 @@ void start_mysongs()
 		else
 			songlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("mysongs-songs-list-unscrollable"));	
 
-		clutter_actor_lower(jammo_get_actor_by_id("mysongs_right-index"),jammo_get_actor_by_id("mysongs_down-index"));
 		clutter_actor_lower(CLUTTER_ACTOR(songlist),jammo_get_actor_by_id("mysongs_down-index"));
-		clutter_actor_raise_top(jammo_get_actor_by_id("mysongs_view_gotocommunity"));
-		clutter_actor_raise_top(jammo_get_actor_by_id("mysongs_view_gohome"));
 
 		for(int i = 0; i < numberOfLoops; i++)
 			mysongs_add_loop_to_list(NULL, i);	
@@ -58,13 +56,13 @@ void start_mysongs()
 
 void mysongs_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
-	mysongs_clear_container(songlist);
+	clear_container(songlist);
 	start_communitymenu();
 }
 
 void mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
-	mysongs_clear_container(songlist);
+	clear_container(songlist);
 	startmenu_goto_startmenu(tanglebutton, none);
 }
 
@@ -86,31 +84,51 @@ void mysongs_autoscroll_to_correct_pos(ClutterActor *listToScroll)
 
 gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops)
 {
-	ClutterActor *avatarImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL);
-	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);
-	ClutterActor *text = clutter_text_new_with_text("Courier 20", "Kysymys Tähän.");	
+	int type = 0;
+	int i;
 
-	ClutterActor *commentButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-					"/opt/jammo/communitymenu/community_comment_icon.png", NULL));
+	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar12.png",NULL);
+	ClutterActor *text = clutter_text_new_with_text("Courier 20", "Test");	
+	ClutterActor *infoButton = NULL;
+
+	for(i = 0; i < numberOfLoops; i++)
+	{
+		if(type == 0) {//TODO Type of the button is determined by the state of the song eg. work in process, video missing etc.
+			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
+				"/opt/jammo/communitymenu/community_comment_icon.png", NULL));
+		}
+		else if(type == 1) {
+			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
+				"/opt/jammo/communitymenu/community_mentor_icon.png", NULL));
+			clutter_actor_set_height(infoButton, clutter_actor_get_height(colorbar));
+		}
+		else {
+			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
+				"/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
+		}
+		type++;
+	}
 
 	ClutterContainer *listContainer = clutter_group_new();
 
-	if(avatarImage == NULL || colorbar == NULL)
+	if(colorbar == NULL || infoButton == NULL)
+	{
+		printf("Failed to load Colorbar or infoButton\n");
 		return FALSE;	
+	}
 
-	if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(avatarImage);
+	if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(colorbar);
 
 	clutter_container_add_actor(listContainer, colorbar);		//Add components inside the container
-	clutter_container_add_actor(listContainer, avatarImage);
 
 	clutter_actor_set_position(text, 60, 23);			
 	clutter_container_add_actor(listContainer, text);
 	
-	clutter_actor_set_position(commentButton, 690, 15);
-	clutter_container_add_actor(listContainer, commentButton);
+	clutter_actor_set_position(infoButton, 690, 0);
+	clutter_container_add_actor(listContainer, infoButton);
 
-	g_signal_connect_swapped(CLUTTER_ACTOR(commentButton), "clicked", G_CALLBACK(mysongs_comment), 
-						clutter_actor_get_parent(commentButton));
+	g_signal_connect_swapped(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_comment), 
+						clutter_actor_get_parent(infoButton));
 
 	clutter_container_add_actor(songlist, CLUTTER_ACTOR(listContainer));
 
@@ -123,7 +141,6 @@ gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops)
 	return TRUE;
 }
 
-
 void mysongs_comment(ClutterActor *actor)
 {
 	GList *children = clutter_container_get_children(songlist); //Get list of actors
@@ -148,30 +165,3 @@ void mysongs_comment(ClutterActor *actor)
 
 	g_list_free(children);
 }
-
-void mysongs_clear_container(ClutterContainer *listToClear)
-{
-	int i = 0;
-
-	if(listToClear != NULL)
-	{
-	 	
-		GList *listItems;
-		listItems = clutter_container_get_children(listToClear);
-	
-		if(listItems != NULL)
-		{
-			do
-			{
-				if(i > 0)
-					listItems = listItems->next;
-				
-				clutter_container_remove_actor(CLUTTER_CONTAINER(listToClear), CLUTTER_ACTOR(listItems->data));
-				i++;
-	
-			}while(listItems->next != NULL);
-	
-			g_list_free(listItems);
-		}
-	}
-}
