@@ -3,7 +3,7 @@
 
 #include <glib.h>
 
-void start_thread_view(GList*);
+void start_thread_view(GList*, gchar *id_, gchar *params);
 void add_message_to_list(gpointer);
 void add_comment();
 void end_single_thread();
