@@ -14,6 +14,8 @@ This is the sequencer.
 #include "communitymenu.h"
 
 #include "../../cem/cem.h"
+#include "../../configure.h"
+#include <libintl.h> //For gettext
 
 void startmenu_goto_sequencer (TangleButton* tanglebutton, gpointer none){
 	start_gamesmenu(); //When level starts, it suppose that gamesmenu is also visible
@@ -52,8 +54,10 @@ void startmenu_right_arrow_clicked(TangleButton* tanglebutton, gpointer none){
 
 
 void startmenu_draw_version_information(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+
 	//Show version number: defined in configure.ac
-	gchar* version = g_strdup_printf("Version-%s",VERSION);
+	/* TRANSLATORS: This is used on startmenu to concatenate Version-0.7.7 */
+	gchar* version = g_strdup_printf("%s-%s",gettext("Version"),VERSION);
 	ClutterActor* version_label = clutter_text_new_with_text ("Luxi Mono 36",version);
 	ClutterColor text_color = { 255, 255, 0, 255 };
 	clutter_actor_set_x(version_label,10.0);
