@@ -33,6 +33,8 @@ enum {
 
 enum {
 	DROPPING_INCOMPATIBLE_SAMPLE,
+	SAMPLE_ADDED,
+	SAMPLE_REMOVED,
 	LAST_SIGNAL
 };
 
@@ -74,6 +76,12 @@ static void marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                 const GValue *param_values,
                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data);
+static void marshal_VOID__INT_OBJECT (GClosure     *closure,
+                          GValue       *return_value G_GNUC_UNUSED,
+                          guint         n_param_values,
+                          const GValue *param_values,
+                          gpointer      invocation_hint G_GNUC_UNUSED,
+                          gpointer      marshal_data);
 
 ClutterActor* jammo_editing_track_view_new(JammoEditingTrack* track, guint n_slots, guint64 slot_duration, gfloat slot_width, gfloat slot_height) {
 
@@ -591,6 +599,25 @@ static void jammo_editing_track_view_class_init(JammoEditingTrackViewClass* trac
 							     G_TYPE_BOOLEAN, 1,
 							     JAMMO_TYPE_SAMPLE_BUTTON);
 
+		signals[SAMPLE_ADDED] = g_signal_new("sample-added", G_TYPE_FROM_CLASS(gobject_class),
+                                G_SIGNAL_RUN_LAST, 0,
+                                NULL, NULL,
+                                marshal_VOID__INT_OBJECT,
+                                G_TYPE_NONE, //return type of handler-function
+                                2, //Number of parameters
+                                G_TYPE_INT, //type of 1st parameter (slot)
+                                JAMMO_TYPE_SAMPLE_BUTTON);  //type of 2nd parameter
+
+
+		signals[SAMPLE_REMOVED] = g_signal_new("sample-removed", G_TYPE_FROM_CLASS(gobject_class),
+                                G_SIGNAL_RUN_LAST, 0,
+                                NULL, NULL,
+                                marshal_VOID__INT_OBJECT,
+                                G_TYPE_NONE, //return type of handler-function
+                                2, //Number of parameters
+                                G_TYPE_INT, //type of 1st parameter (slot)
+                                JAMMO_TYPE_SAMPLE_BUTTON);  //type of 2nd parameter
+
 
 	g_type_class_add_private (gobject_class, sizeof (JammoEditingTrackViewPrivate));
 }
@@ -627,12 +654,14 @@ static void on_actor_removed(TangleWidget* widget, ClutterActor* actor, gpointer
 	
 	track_view = JAMMO_EDITING_TRACK_VIEW(widget);
 	sample_button = JAMMO_SAMPLE_BUTTON(actor);
-	
+
+	guint slot = clutter_actor_get_x(actor) / track_view->priv->slot_width;
+	g_signal_emit(track_view, signals[SAMPLE_REMOVED], 0, slot,sample_button);
+
 	jammo_editing_track_remove_sample(track_view->priv->track, jammo_sample_button_get_sample(sample_button));
 
 	//If editing is not allowed, this actor was removed by network and should not been informed to gems
 	if (track_view->priv->editing_enabled) {
-		guint slot = clutter_actor_get_x(actor) / track_view->priv->slot_width;
 		gems_remove_sample_from_slot(slot);
 	}
 
@@ -760,11 +789,14 @@ static void on_dropped(TangleDropAction* drop_action, TangleDragAction* drag_act
 	clutter_actor_get_size(drag_actor, &w, &h);
 	if (clutter_actor_transform_stage_point(CLUTTER_ACTOR(track_view), actor_x, actor_y, &x, &y) &&
 	    clutter_actor_transform_stage_point(CLUTTER_ACTOR(track_view), actor_x + w / 2, actor_y + h / 2, &center_x, &center_y)) {
+
+		//Default=types are not strict.
+		//Signal-listener can return FALSE -> then dropping incompatible is prohibited
 		if (track_view->priv->sample_type != JAMMO_SAMPLE_UNTYPED &&
 		     jammo_sample_button_get_sample_type(JAMMO_SAMPLE_BUTTON(meta_actor)) != track_view->priv->sample_type &&
 		     jammo_sample_button_get_sample_type(JAMMO_SAMPLE_BUTTON(meta_actor)) != JAMMO_SAMPLE_UNTYPED) {
-		     	accepted = FALSE;
-			g_signal_emit(track_view, signals[DROPPING_INCOMPATIBLE_SAMPLE], 0, drag_actor, &accepted);
+			accepted = TRUE;
+			g_signal_emit(track_view, signals[DROPPING_INCOMPATIBLE_SAMPLE], 0, meta_actor, &accepted);
 		}
 	}
 
@@ -792,7 +824,9 @@ static void on_dropped(TangleDropAction* drop_action, TangleDragAction* drag_act
 
 		clutter_actor_animate(copy_of_sample_button, CLUTTER_EASE_OUT_CUBIC, 300, "x", slot * track_view->priv->real_slot_width, "y", 0.0, NULL);
 
-		gems_add_new_sample_to_track(jammo_sample_button_get_loop_id(sample_button), slot);
+		g_signal_emit(track_view, signals[SAMPLE_ADDED], 0, slot,copy_of_sample_button);
+		jammo_sample_button_on_dropped(sample_button);
+		gems_add_new_sample_to_track(jammo_sample_button_get_loop_id(sample_button), slot); //FIXME: remove this: signal emitting is enough
 	}
 }
 
@@ -801,12 +835,14 @@ static void on_dropped(TangleDropAction* drop_action, TangleDragAction* drag_act
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_object(v)   g_value_get_object (v)
+#define g_marshal_value_peek_int(v)      g_value_get_int (v)
 #else /* !G_ENABLE_DEBUG */
 /* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
  *          Do not access GValues directly in your code. Instead, use the
  *          g_value_get_*() functions
  */
 #define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
+#define g_marshal_value_peek_int(v)      (v)->data[0].v_int
 #endif /* !G_ENABLE_DEBUG */
 
 void marshal_BOOLEAN__OBJECT (GClosure     *closure,
@@ -846,3 +882,38 @@ void marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
+//Generated with: echo "VOID:INT,OBJECT" | glib-genmarshal --body --prefix=marshal
+void marshal_VOID__INT_OBJECT (GClosure     *closure,
+                          GValue       *return_value G_GNUC_UNUSED,
+                          guint         n_param_values,
+                          const GValue *param_values,
+                          gpointer      invocation_hint G_GNUC_UNUSED,
+                          gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT_OBJECT) (gpointer     data1,
+                                                 gint         arg_1,
+                                                 gpointer     arg_2,
+                                                 gpointer     data2);
+  register GMarshalFunc_VOID__INT_OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT_OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_int (param_values + 1),
+            g_marshal_value_peek_object (param_values + 2),
+            data2);
+}
