@@ -61,7 +61,6 @@ struct _JammoGameTaskPrivate {
 static guint signals[LAST_SIGNAL] = { 0 };
 static ClutterScriptableIface* parent_scriptable_iface = NULL;
 
-static void hide_actor(ClutterActor* actor, gpointer user_data);
 static gint act_compare_name(Act* act, const gchar* name);
 
 static void marshal_VOID__STRING_UINT (GClosure     *closure,
@@ -567,16 +566,6 @@ static void clutter_scriptable_iface_init(ClutterScriptableIface* iface) {
 }
 
 
-static void hide_actor(ClutterActor* actor, gpointer user_data) {
-	if (actor != user_data) {
-		if (TANGLE_IS_ACTOR(actor)) {
-			tangle_actor_hide_animated(TANGLE_ACTOR(actor));
-		} else {
-			clutter_actor_hide(actor);
-		}
-	}
-}
-
 static gint act_compare_name(Act* act, const gchar* name) {
 
 	return strcmp(act->name, name);
