@@ -42,6 +42,9 @@
 #include "../gems/gems.h"
 //#include "singinggame.h"
 
+#include <libintl.h> //For gettext
+
+
 #ifdef N900
 #include <libosso.h>
 #include <clutter/x11/clutter-x11.h>
@@ -280,11 +283,11 @@ int main(int argc, char** argv) {
 	
 	/* GEMS initialization and profile manager test */
 #ifdef NETWORKING_ENABLED
-	GRand* grand = g_rand_new_with_seed(time(NULL));
+	//GRand* grand = g_rand_new_with_seed(time(NULL));
 	jammo_gems_init(argc, argv);
-	gems_profile_manager_login(g_rand_int(grand),NULL,NULL);
+	//gems_profile_manager_login(g_rand_int(grand),NULL,NULL);
 	//printf("Selected random ID = %u\n",gems_profile_manager_get_userid(NULL));
-	g_rand_free(grand);
+	//g_rand_free(grand);
 	
 	gems_enable_network_timeout_functions();
 	
@@ -317,6 +320,16 @@ int main(int argc, char** argv) {
 
 	create_directories();
 
+	/* PACKAGE from configure.ac */ \
+	setlocale ( LC_ALL, "" );
+	bindtextdomain ( PACKAGE, "/opt/jammo/languages" );
+	textdomain ( PACKAGE );
+
+	/* TRANSLATORS: This is used on main, when gettext is first time used */
+	gchar* localized = g_strdup_printf("main: %s",_("gettext initialized"));
+	message = g_strdup_printf("%s",localized);
+	cem_add_to_log(message, J_LOG_DEBUG);
+	g_free(message);
 
 	/* TODO: Temporary: make sure Mentor classes exists. */
 	/* And orientation games related */
@@ -387,6 +400,8 @@ int main(int argc, char** argv) {
 	cem_add_to_log(message, J_LOG_DEBUG);
 	g_free(message);
 
+
+
 	gchar* lang2=g_strndup (lang,5); //omit charset.
 	gchar* path;
 	if (!strcmp(application_name,"jammo7_12"))
