@@ -146,10 +146,25 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 		//VALIDATE PASSWORD MISSING 
 		if (pg_validate_gesture(password)) {
 			pg_save_passwd(password);
-			pg_set_reset_success_screen(stage, PG_RESET_PASSWORD_SUCCESS);
-			return TRUE;
+			
+			/* A temporary solution for changing password at login screen - the user should be already logged
+			 * in to change the password, this just discards the old profile and creates new with default data */
+			// Input password and age for creating default user, uses random numbers to generate id
+			gems_profile_manager_create_default_user_profile(password,9);
+			
+			// Authenticate
+			if(gems_profile_manager_authenticate_default_user(password) == LOGIN_OK)
+			{
+				pg_set_reset_success_screen(stage, PG_RESET_PASSWORD_SUCCESS);
+				return TRUE;
+			}
+			else
+			{
+				pg_set_error_screen(stage, PG_RESET_PASSWORD_ERROR);
+				return TRUE;
+			}
 		} else {
-			pg_set_error_screen(stage, PG_RESET_PASSWORD_ERROR);
+			pg_set_error_screen(stage, PG_PASSWORD_ERROR);
 			return TRUE;
 		}
 
@@ -160,6 +175,53 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 
 		g_print("Knots are => %s, File data => %s\n", password, user_passwd);
 
+		switch(gems_profile_manager_authenticate_default_user(password))
+		{
+			// No profile installed (for defaultuser)
+			case LOGIN_NO_PROFILE:
+				// First create new profile with given password
+				// TODO Check returnvalues and react
+				gems_profile_manager_create_default_user_profile(password,9);
+				
+				// Authenticate - should always succeed, hence previous function call!
+				if(gems_profile_manager_authenticate_default_user(password) == LOGIN_OK)
+				{
+					clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
+					clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
+					return TRUE;
+				}
+				// This shouldn't really happen since a default profile with
+				// the provided password was created
+				else
+				{
+					pg_set_error_screen(stage, PG_PASSWORD_ERROR);
+					return TRUE;
+				}
+			
+			// Login ok!
+			case LOGIN_OK:
+				clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
+				clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
+				return TRUE;
+			
+			// Invalid password
+			case LOGIN_INVALID_PASSWORD:
+				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
+				return TRUE;
+			
+			// Errorcases ...
+			// TODO react to these
+			case LOGIN_PROFILE_CORRUPT:
+			case LOGIN_PROFILE_HASH_FAIL:
+			case LOGIN_CANNOT_INIT_PASSWD:
+			case LOGIN_CANNOT_INIT_SECURITY:
+			case LOGIN_INVALID_PARAMS:
+			default:
+				// Go to error screen if other error occurs
+				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
+				return TRUE;
+		}
+
 		if (strcmp(password, user_passwd) == 0) {
 			clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
 			clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
@@ -172,17 +234,20 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 
 int *get_user_passwd() {
 	//Should read passwords as strings from profiler
-	int user_id;
-	gchar *username = "Guest";
-	gchar *passworddata = "password";
-	gint dummy_login;
-	user_id = gems_profile_manager_get_userid(NULL);
-	dummy_login = gems_profile_manager_login(user_id, username, passworddata);
-	if (dummy_login) {
+	//int user_id;
+	//gchar *username = "Guest";
+	//gchar *passworddata = "password";
+	//gint dummy_login;
+	
+	// Login should be done right after giving password
+	//user_id = gems_profile_manager_get_userid(NULL);
+	//dummy_login = gems_profile_manager_login(user_id, username, passworddata);
+	//if (dummy_login) {
 		//g_print("DUMMY LOGIN BAD\n");
-	} else {
+	//} else {
 		//g_print("DUMMY LOGIN GOOD\n");
-	}
+	//}
+	
 	int *pass_arr;
 	pass_arr = malloc(4 * sizeof *pass_arr);
 	pass_arr[0] = 1;
