@@ -108,7 +108,7 @@ gchar* save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gcha
 			g_type_class_unref(enum_class);
 			if (enum_value) {
 				const gchar* nick = enum_value->value_nick;
-				fprintf(ofp,"\t\"editing-track-type:\" : \"%s\",\n",nick);
+				fprintf(ofp,"\t\"editing-track-type\" : \"%s\",\n",nick);
 			}
 
 			fprintf(ofp,"\t\"samples\" : [\n");
@@ -130,9 +130,19 @@ gchar* save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gcha
 				//printf("x: '%lf' \n",clutter_actor_get_x(CLUTTER_ACTOR(jsb)));
 				printf("slot: '%lf' \n",clutter_actor_get_x(CLUTTER_ACTOR(jsb))/slot_size);
 				fprintf(ofp,"\t\t{\n");
-				gint loop_id;
-				g_object_get(jsb, "loop_id", &loop_id, NULL);
-				fprintf(ofp,"\t\t\"loop_id\" : %d,\n",loop_id);
+
+				//Not saving anymore loop_id. composition_game_file_helper can read old 'format' still
+				//gint loop_id;
+				//g_object_get(jsb, "loop_id", &loop_id, NULL);
+				//fprintf(ofp,"\t\t\"loop_id\" : %d,\n",loop_id);
+
+				gchar* image_filename;
+				g_object_get(jsb, "image-filename", &image_filename, NULL);
+				fprintf(ofp,"\t\t\"image\" : \"%s\",\n",image_filename);
+
+				gchar* audio_filename;
+				g_object_get(jsb, "sample-filename", &audio_filename, NULL);
+				fprintf(ofp,"\t\t\"audio\" : \"%s\",\n",audio_filename);
 
 				gint slot = clutter_actor_get_x(CLUTTER_ACTOR(jsb))/slot_size;
 				fprintf(ofp,"\t\t\"slot\" : %d\n",slot);
@@ -246,3 +256,64 @@ gchar* save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gcha
 	return final_filename;
 }
 
+
+
+/*
+ * JsonNode *sub_node is 'samples' -array
+ * JammoEditingTrackView* track_view is target JammoEditingTrackView
+ * gboolean reactive : reactivity of each new jammo_sample_button
+ */
+void load_this_sample_array_to_this_track_view(JsonNode *sub_node,JammoEditingTrackView* track_view, gboolean reactive) {
+	//Array
+	//sub_node = json_object_get_member (sub_object, "samples");
+	if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_ARRAY){
+		JsonArray* sample_array =  json_node_get_array (sub_node);
+
+		guint length = json_array_get_length(sample_array);
+		//printf("length %d\n",length);
+		int i;
+		for (i=0;i<length;i++) {
+			JsonNode* sample_node;
+			sample_node = json_array_get_element(sample_array,i);
+			if (sample_node!=NULL && JSON_NODE_TYPE(sample_node) == JSON_NODE_OBJECT){
+				JsonObject* sample_object = json_node_get_object(sample_node);
+				gint slot=-1;
+				gchar* image_file=NULL;
+				gchar* audio_file=NULL;
+
+				//string
+				sub_node = json_object_get_member (sample_object, "image");
+				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+					image_file =(gchar*)  json_node_get_string (sub_node);
+					printf("image: '%s'\n",image_file);
+				}
+				//string
+				sub_node = json_object_get_member (sample_object, "audio");
+				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+					audio_file =(gchar*)  json_node_get_string (sub_node);
+					printf("audio: '%s'\n",audio_file);
+				}
+
+				//int
+				sub_node = json_object_get_member (sample_object, "slot");
+				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+					slot =  json_node_get_int (sub_node);
+					//printf("slot: '%d'\n",slot);
+				}
+				if (track_view) {
+					ClutterActor* sample_button=NULL;
+					if (image_file && audio_file)
+						sample_button = jammo_sample_button_new_from_files(image_file, audio_file);
+					if (sample_button) {
+						jammo_editing_track_view_add_jammo_sample_button(track_view,JAMMO_SAMPLE_BUTTON(sample_button),slot);
+						clutter_actor_set_reactive(sample_button,reactive);
+					} //sample_button!=NULL check
+				} //track!=NULL check
+
+			} //This sample-object is ready
+
+		} //Foreach in sample-array ready
+
+	} //sample-array is ready
+
+}
