@@ -37,6 +37,7 @@ ProfileManager* ProfileManager::GetInstance()
 // Constructor
 ProfileManager::ProfileManager()
 {
+	iSavingRequired = FALSE;
 	iStorageAgent = new StorageAgent();
 	// process agent not yet used.
 	//iProcessAgent = NULL;
@@ -61,19 +62,23 @@ ProfileManager::~ProfileManager()
 // profile data
 gboolean ProfileManager::Login(guint32 userID)
 {
+	gchar* logmsg = g_strdup_printf("ProfileManager::Login() : attempted to use deprecated function!");
+	log_wrap(logmsg, J_LOG_ERROR);
+	g_free(logmsg);
+	return FALSE;
 	// Store the id
-	iUser = userID;
+	//iUser = userID;
 	
-	string msg = "User Profile ";
+	//string msg = "User Profile ";
 	// C++ type int to string conversion
-	stringstream user;
-	user << userID;
-	msg.append(user.str());
+	//stringstream user;
+	//user << userID;
+	//msg.append(user.str());
 	
 	// If profile can be retrieved correctly,
 	// create a server for displaying the profile
 	// to other users
-	if (iStorageAgent->Retrieve(iUser) == true)
+	/*if (iStorageAgent->Retrieve(iUser) == true)
 	{
 		msg.append(" succesfully retrieved");
 		log_wrap((char*)msg.c_str(),J_LOG_INFO);
@@ -81,51 +86,54 @@ gboolean ProfileManager::Login(guint32 userID)
 	}
 	else
 	{
-		//cout << "Error while retrieving user profile data";
 		msg.append(" cannot be found.");
 		log_wrap((char*)msg.c_str(),J_LOG_INFO);
 		return false;
-	}
+	}*/
 	
 }
 
 // Logout
 gboolean ProfileManager::Logout()
 {
+	// Not logged in, cannot log out
+	if(!isAuthenticated()) return FALSE;
+	
+	// Clear the user from the memory
+	iUser = 0;
+	// Clear data (sets authenticated to FALSE)
+	iStorageAgent->clearDetails();
+	// Clear encrypted data, should be saved before logout
+	iStorageAgent->clearEncryptedData();
 
-	// Store the user data
-	
-	if (iStorageAgent->Store(iUser) == true)
-	{
-	
-		// Clear the user from the memory
-		iUser = 0;
-		iStorageAgent->clearDetails();
-	
-		// If everything worked correctly, return true
-		// Again... not implemented correctly
-		return true;
-	}
-	
+	return TRUE;
 }
 
 string ProfileManager::ViewDetails()
 {
-	// View my details here
-	return iStorageAgent->getDetails();
+	// check if authenticated
+	if(isAuthenticated()) return iStorageAgent->getDetails();
+	else return "";
 }
 
 string ProfileManager::ViewDetail(string& detail)
 {
-	return iStorageAgent->getDetail(detail);
+	if(isAuthenticated()) return iStorageAgent->getDetail(detail);
+	else return "";
 }
 
 // Edit user details. Takes the name of the detail and the new Value
 // as a string
 gboolean ProfileManager::EditDetails(string& detail, string& newValue)
 {
+	// Cannot set details if not authenticated
+	if(!isAuthenticated()) return FALSE;
+	
 	// If the detail changing operation is failure, function return false
-	return iStorageAgent->setDetails(detail, newValue);
+	if(!iStorageAgent->setDetails(detail, newValue)) return FALSE;
+	// Changed, requires saving
+	iSavingRequired = TRUE;
+	return TRUE;
 }
 
 // This function is used to Force another user in to the
@@ -157,11 +165,125 @@ guint32 ProfileManager::GetId()
 	return iUser;
 }
 
-StorageAgent* ProfileManager::GetStorageAgent()
+gboolean ProfileManager::loadEncryptedProfile(gchar* _username)
 {
-	return iStorageAgent;
+	return iStorageAgent->loadEncryptedProfile(_username);
 }
 
+gboolean ProfileManager::saveEncryptedProfile()
+{
+	string param = string(PROF_PARAM_USERNAME);
+	gchar* username = (gchar*)ViewDetail(param).c_str();
+	if(iStorageAgent->saveEncryptedProfile(username))
+	{
+		iSavingRequired = FALSE;
+		return TRUE;
+	}
+	else
+	{
+		iSavingRequired = TRUE;
+		return FALSE;
+	}
+}
+
+gboolean ProfileManager::changeLoadedUser(gchar* _username)
+{
+	// clear previous user data
+	iStorageAgent->clearEncryptedData();
+	iStorageAgent->clearDetails();
+	// Load new
+	return loadEncryptedProfile(_username);
+}
+
+gboolean ProfileManager::deserializeProfile(gchar* _profile)
+{
+	gboolean rval = iStorageAgent->deserializeProfile(_profile);
+	
+	if(rval)
+	{
+		string param = string(PROF_PARAM_USERID);
+		iUser = (guint32)strtoul(iStorageAgent->getDetail(param).c_str(),NULL,10);
+	}
+	return rval;
+}
+
+gchar* ProfileManager::serializeProfile()
+{
+	return iStorageAgent->serializeProfile();
+}
+
+guchar* ProfileManager::getSalt()
+{
+	return iStorageAgent->getSalt();
+}
+
+guchar* ProfileManager::getPasswordHash()
+{
+	return iStorageAgent->getPasswordHash();
+}
+
+guchar* ProfileManager::getProfileHash()
+{
+	return iStorageAgent->getProfileHash();
+}
+
+guchar* ProfileManager::getEncryptedProfile()
+{
+	return iStorageAgent->getEncryptedProfile();
+}
+
+guint ProfileManager::getEncryptedProfileSize()
+{
+	return iStorageAgent->getEncryptedProfileSize();
+}
+
+gboolean ProfileManager::setSalt(guchar* _salt)
+{
+	if(!iStorageAgent->isAuthenticated()) return iStorageAgent->setSalt(_salt);
+	else return FALSE;
+}
+
+gboolean ProfileManager::setPasswordHash(guchar* _password_hash)
+{
+	if(iStorageAgent->isAuthenticated()) return iStorageAgent->setPasswordHash(_password_hash);
+	else return FALSE;
+}
+
+gboolean ProfileManager::setEncryptedProfile(guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size)
+{
+	if(iStorageAgent->isAuthenticated())
+	{
+		if(iStorageAgent->setEncryptedProfile(_profile_hash, _encrypted_profile, _e_profile_size))
+		{
+			iSavingRequired = FALSE;
+			return TRUE;
+		}
+		else
+		{
+			iSavingRequired = TRUE;
+			return FALSE;
+		}
+	}
+	else return FALSE;
+}
+
+gboolean ProfileManager::isSavingRequired()
+{
+	return iSavingRequired;
+}
+
+gboolean ProfileManager::isAuthenticated()
+{
+	return iStorageAgent->isAuthenticated();
+}
+
+// TODO add checks for this
+gboolean ProfileManager::setAuthenticated()
+{
+	return iStorageAgent->setAuthenticated();
+}
+	
+
 void log_wrap(char* msg, int info)
 {
 	cem_add_to_log(msg,info);
@@ -248,7 +370,7 @@ guint16 profilemanager_get_age(ProfileManager* _aManager)
 guint32 profilemanager_get_points(ProfileManager* _aManager)
 {
 	string param = string(PROF_PARAM_POINTS);
-	return (guint32)atoi(_aManager->ViewDetail(param).c_str());
+	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 }
 
 gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value)
@@ -288,7 +410,7 @@ gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value)
 gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value)
 {
 	string param = string(PROF_PARAM_POINTS);
-	guint32 points = atoi((_aManager->ViewDetail(param)).c_str());
+	guint32 points = (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 	
 	points += _value;
 	
@@ -303,7 +425,7 @@ gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value)
 gboolean profilemanager_remove_points(ProfileManager* _aManager, guint32 _value)
 {
 	string param = string(PROF_PARAM_POINTS);
-	guint32 points = atoi((_aManager->ViewDetail(param)).c_str());
+	guint32 points = (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 	
 	if((points - _value) < 0) points = 0;
 	else points = points - _value;
@@ -323,48 +445,87 @@ void profilemanager_reset_points(ProfileManager* _aManager)
 	_aManager->EditDetails(param,value);
 }
 
+gboolean profilemanager_storage_load_profile(ProfileManager* _aManager, gchar* _username)
+{
+	return _aManager->loadEncryptedProfile(_username);
+}
+
+gboolean profilemanager_storage_save_profile(ProfileManager* _aManager)
+{
+	return _aManager->saveEncryptedProfile();
+}
+
+gboolean profilemanager_storage_change_profile(ProfileManager* _aManager, gchar* _username)
+{
+	return _aManager->changeLoadedUser(_username);
+}
+
 guchar* profilemanager_storage_get_password_salt(ProfileManager* _aManager)
 {
 	if(_aManager == NULL) return NULL;
-	return _aManager->GetStorageAgent()->getSalt();
+	return _aManager->getSalt();
 }
 
 guchar* profilemanager_storage_get_password_hash(ProfileManager* _aManager)
 {
 	if(_aManager == NULL) return NULL;
-	return _aManager->GetStorageAgent()->getPasswordHash();
+	return _aManager->getPasswordHash();
 }
 
 guchar* profilemanager_storage_get_profile_hash(ProfileManager* _aManager)
 {
 	if(_aManager == NULL) return NULL;
-	return _aManager->GetStorageAgent()->getProfileHash();
+	return _aManager->getProfileHash();
 }
 
 guchar* profilemanager_storage_get_encrypted_profile(ProfileManager* _aManager)
 {
 	if(_aManager == NULL) return NULL;
-	return _aManager->GetStorageAgent()->getEncryptedProfile();
+	return _aManager->getEncryptedProfile();
 }
 
 guint profilemanager_storage_get_encrypted_profile_size(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
-	return _aManager->GetStorageAgent()->getEncryptedProfileSize();
+	if(_aManager == NULL) return 0;
+	return _aManager->getEncryptedProfileSize();
 }
 
-void profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt)
+gboolean profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt)
 {
-	_aManager->GetStorageAgent()->setSalt(_salt);
+	return _aManager->setSalt(_salt);
 }
 
-void profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash)
+gboolean profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash)
 {
-	_aManager->GetStorageAgent()->setPasswordHash(_hash);
+	return _aManager->setPasswordHash(_hash);
 }
 
-void profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size)
+gboolean profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size)
 {
-	_aManager->GetStorageAgent()->setEncryptedProfile(_profile_hash, _encrypted_profile, _e_profile_size);
+	return _aManager->setEncryptedProfile(_profile_hash, _encrypted_profile, _e_profile_size);
+}
+
+gboolean profilemanager_storage_deserialize_profile(ProfileManager* _aManager, guchar* _profile)
+{
+	return _aManager->deserializeProfile((gchar*)_profile);
+}
+
+gchar* profilemanager_storage_serialize_profile(ProfileManager* _aManager)
+{
+	return _aManager->serializeProfile();
+}
+
+gboolean profilemanager_set_authenticated(ProfileManager* _aManager)
+{
+	return _aManager->setAuthenticated();
+}
+
+gboolean profilemanager_is_authenticated(ProfileManager* _aManager)
+{
+	return _aManager->isAuthenticated();
+}
+gboolean profilemanager_is_saving_required(ProfileManager* _aManager)
+{
+	return _aManager->isSavingRequired();
 }
 
