@@ -149,6 +149,9 @@ void jammo_gems_init(int argc, char* argv[])
 	// All components
 	gems_components* components = gems_get_data();
 	
+	// Initialize timeout function id table
+	for(gint i = 0; i < 9; i++) components->timeout_functions[i] = 0;
+	
 	// Profile manager
 	components->pm = profilemanager_new_manager();
 	
@@ -239,6 +242,9 @@ void jammo_gems_cleanup()
 	cem_add_to_log(logmsg,J_LOG_DEBUG);
 	g_free(logmsg);
 	
+	// Remove timeout functions
+	for(gint i = 0; i<9; i++) g_source_remove(components->timeout_functions[i]);
+	
 	if(components->pm != NULL) profilemanager_delete_manager(components->pm);
 	
 	// Clean lists
@@ -260,9 +266,12 @@ void jammo_gems_cleanup()
 	gems_service_group_cleanup();
 	
 	// Clear Collaboration service related
-	if(components->service_group->enabled == TRUE) ph_c_unregister_service(components->ph,COLLABORATION_SERVICE_NAME);
+	if(components->service_collaboration->enabled == TRUE) ph_c_unregister_service(components->ph,COLLABORATION_SERVICE_NAME);
 	gems_service_collaboration_cleanup();
 	
+	if(components->service_control->enabled == TRUE) ph_c_unregister_service(components->ph,CONTROL_SERVICE_NAME);
+	gems_service_control_cleanup();
+	
 	gems_clear_teacher_connection();
 	
 	// delete peerhood
@@ -732,7 +741,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 }
 
 gint gems_process_connections()
-{
+{	
 	gems_components* data = gems_get_data();
 	
 	gboolean cleanup_required = FALSE;
@@ -1029,15 +1038,15 @@ void gems_init_peerhood_callback()
  */
 void gems_enable_network_timeout_functions()
 {
-	g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_process_connections, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_service_jammo_process_connections, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_search_jammos, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,300,(GSourceFunc)gems_communication_retrieve_profiles, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_process_connecting, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_communication_process_connected, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,500,(GSourceFunc)gems_communication_process_rejected, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_request_groups, NULL, NULL);
-	g_timeout_add_full(G_PRIORITY_HIGH,350,(GSourceFunc)gems_communication_sanitize_grouplist, NULL, NULL);
+	gems_get_data()->timeout_functions[0] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_process_connections, NULL, NULL);
+	gems_get_data()->timeout_functions[1] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_service_jammo_process_connections, NULL, NULL);
+	gems_get_data()->timeout_functions[2] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_search_jammos, NULL, NULL);
+	gems_get_data()->timeout_functions[3] = g_timeout_add_full(G_PRIORITY_HIGH,300,(GSourceFunc)gems_communication_retrieve_profiles, NULL, NULL);
+	gems_get_data()->timeout_functions[4] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_process_connecting, NULL, NULL);
+	gems_get_data()->timeout_functions[5] = g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_communication_process_connected, NULL, NULL);
+	gems_get_data()->timeout_functions[6] = g_timeout_add_full(G_PRIORITY_HIGH,500,(GSourceFunc)gems_communication_process_rejected, NULL, NULL);
+	gems_get_data()->timeout_functions[7] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_request_groups, NULL, NULL);
+	gems_get_data()->timeout_functions[8] = g_timeout_add_full(G_PRIORITY_HIGH,350,(GSourceFunc)gems_communication_sanitize_grouplist, NULL, NULL);
 }
 
 void gems_register_services()
