@@ -261,10 +261,22 @@ typedef enum
 #define SECURITY_CORRUPT_MESSAGE 10191 // hash value in envelope doesn't match the content
 #define SECURITY_VERIFY_FAILED 10192 // cannot verify the signature of hash
 
+// authentication returnvalues
+#define LOGIN_NO_PROFILE -1
+#define LOGIN_OK 0
+#define LOGIN_INVALID_PARAMS 1
+#define LOGIN_CANNOT_INIT_PASSWD 2
+#define LOGIN_CANNOT_INIT_SECURITY 3
+#define LOGIN_INVALID_PASSWORD 4
+#define LOGIN_PROFILE_HASH_FAIL 5
+#define LOGIN_PROFILE_CORRUPT 6
+
+
 // Security vars
 #define AES_ROUNDS 5
 #define AES_SALT_LENGTH 8
 #define PASSLEN 64
+#define SHA_HASH_LENGTH 32
 
 // Default strings for games
 #define GEMS_EMPTY_SONG_INFO "empty song info"
