@@ -59,33 +59,50 @@ gint gems_security_extract_envelope(gems_connection* element)
 	return SECURITY_OK;
 }
 
-gboolean gems_security_init_security(guchar* password_data, guint password_length)
+gboolean gems_security_init_security(guchar* password, guchar* salt)
 {
-	gems_security_context* security = gems_get_security_contexts();
+	gems_components* components = gems_get_data();
+	gems_security_context* security = NULL;
+	
+	guint passlen = PASSLEN;
 	
 	// Not set - allocate struct
-	if(security == NULL) security = (gems_security_context*)g_malloc(sizeof(gems_security_context));
+	if(components->security_context == NULL) components->security_context = (gems_security_context*)g_malloc(sizeof(gems_security_context));
 	
-	security->encryption = (EVP_CIPHER_CTX*)g_malloc(sizeof(EVP_CIPHER_CTX));
-	security->decryption = (EVP_CIPHER_CTX*)g_malloc(sizeof(EVP_CIPHER_CTX));
-	security->digest = (EVP_MD_CTX*)g_malloc(sizeof(EVP_MD_CTX));
+	security = gems_get_security_contexts();
+	security->encryption = OPENSSL_malloc(sizeof *security->encryption);
+	security->decryption = OPENSSL_malloc(sizeof *security->decryption); //(EVP_CIPHER_CTX*)g_malloc(sizeof(EVP_CIPHER_CTX));
+	// According to EVP documentation, this initializes also the content, so EVP_MD_CTX_Init() is not necessary
+	security->digest = EVP_MD_CTX_create(); 
 	
-	// If profile loaded as encrypted - use salt from that
-	// otherwise create new?
-	if(gems_security_init_aes(security->encryption, security->decryption, password_data, password_length,NULL)) return FALSE;
+	// initialize aes
+	// TODO cleanup contexts if errors occur
+	if(!gems_security_init_aes(security->encryption, security->decryption, salt, password, passlen))
+	{
+		// Failures, cleanup contexts
+		OPENSSL_free(security->encryption);
+		security->encryption = NULL;
+		
+		OPENSSL_free(security->decryption);
+		security->decryption = NULL;
+		
+		return FALSE;
+	}
 	
-	// No need to keep the password data - it is set to security contexts
-	g_free(password_data);
-	
-	if(gems_security_init_sha(security->digest)) return FALSE;
+	if(!gems_security_init_sha(security->digest))
+	{
+		OPENSSL_free(security->digest);
+		security->digest = NULL;
+		return FALSE;
+	}
 	
 	return TRUE;
 }
 
-gboolean gems_security_change_password(guchar* password_data, guint password_length)
+gboolean gems_security_change_password(guchar* password,guchar* salt)
 {
 	gems_security_clear_security();
-	if(gems_security_init_security(password_data, password_length))
+	if(gems_security_init_security(password,salt))
 	{
 		cem_add_to_log("gems_security_change_password() : success", J_LOG_DEBUG);
 		return TRUE;
@@ -98,37 +115,70 @@ gboolean gems_security_change_password(guchar* password_data, guint password_len
 	}
 }
 
+guchar* gems_security_create_password(gchar* password_data, guchar* salt)
+{
+	guchar* passwd = NULL;
+	
+	if(password_data == NULL || salt == NULL) return NULL;
+	
+	passwd = (guchar*)g_malloc(sizeof(guchar*)*PASSLEN);
+	memset(passwd,0,PASSLEN);
+	g_memmove(&passwd[0],password_data,strlen(password_data));
+	g_memmove(&passwd[strlen(password_data)],salt,AES_SALT_LENGTH);
+	
+	return passwd;
+}
+
 void gems_security_clear_security()
 {
 	gchar* logmsg = NULL;
 	gems_security_context* security = gems_get_security_contexts();
 	
-	if(EVP_CIPHER_CTX_cleanup(security->encryption) != 1)
-	{
-		logmsg = g_strdup_printf("gems_security_clear_security() : Cannot cleanup encryption context");
-		cem_add_to_log(logmsg,J_LOG_ERROR);
-		g_free(logmsg);
-	}
-	g_free(security->encryption);
+	// No need to clear 
+	if(security == NULL) return;
 	
-	if(EVP_CIPHER_CTX_cleanup(security->decryption) != 1)
+	if(security->encryption != NULL)
 	{
-		logmsg = g_strdup_printf("gems_security_clear_security() : Cannot cleanup decryption context");
-		cem_add_to_log(logmsg,J_LOG_ERROR);
-		g_free(logmsg);
+		if(EVP_CIPHER_CTX_cleanup(security->encryption) != 1)
+		{
+			logmsg = g_strdup_printf("gems_security_clear_security() : Cannot cleanup encryption context");
+			cem_add_to_log(logmsg,J_LOG_ERROR);
+			g_free(logmsg);
+		}
+		OPENSSL_free(security->encryption);
+		security->encryption = NULL;
 	}
-	g_free(security->decryption);
 	
-	if(EVP_MD_CTX_cleanup(security->digest) != 1)
+	if(security->decryption != NULL)
 	{
-		logmsg = g_strdup_printf("gems_security_clear_security() : Cannot cleanup message digest");
-		cem_add_to_log(logmsg,J_LOG_ERROR);
-		g_free(logmsg);
+		if(EVP_CIPHER_CTX_cleanup(security->decryption) != 1)
+		{
+			logmsg = g_strdup_printf("gems_security_clear_security() : Cannot cleanup decryption context");
+			cem_add_to_log(logmsg,J_LOG_ERROR);
+			g_free(logmsg);
+		}
+		OPENSSL_free(security->decryption);
+		security->decryption = NULL;
 	}
-	g_free(security->digest);
 	
-	g_free(security);
-	security = NULL;
+	if(security->digest != NULL)
+	{
+		if(EVP_MD_CTX_cleanup(security->digest) != 1)
+		{
+			logmsg = g_strdup_printf("gems_security_clear_security() : Cannot cleanup message digest");
+			cem_add_to_log(logmsg,J_LOG_ERROR);
+			g_free(logmsg);
+		}
+		//OPENSSL_free(security->digest);
+		// Destroy and free the memory (according to EVP documentation)
+		EVP_MD_CTX_destroy(security->digest);
+		security->digest = NULL;
+	}
+	
+	g_free(gems_get_data()->security_context);
+	gems_get_data()->security_context = NULL;
+	
+	cem_add_to_log("Security contexts cleanup.", J_LOG_DEBUG);
 }
 
 guchar* gems_security_create_password_salt()
@@ -148,7 +198,7 @@ guchar* gems_security_create_password_salt()
 }
 
 // encryption context, decryption context, key/passwd data, key data length, salt
-gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, guchar* keydata, guint keylength, guchar* salt)
+gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, guchar* salt, guchar* keydata, guint keylength)
 {
 	guchar key[32], iv[32];
 	gchar* logmsg = NULL;
@@ -157,7 +207,7 @@ gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, guchar
 	memset(&key,0,32);
 	memset(&iv,0,32);
 	
-	if(EVP_BytesToKey(EVP_aes_256_cbc(),EVP_sha256(), NULL, keydata, keylength, AES_ROUNDS, key, iv) != 32)
+	if(EVP_BytesToKey(EVP_aes_256_cbc(),EVP_sha256(), salt, keydata, keylength, AES_ROUNDS, key, iv) != 32)
 	{
 		logmsg = g_strdup_printf("gems_security_init_aes() : Cannot set bytes to key.");
 		cem_add_to_log(logmsg,J_LOG_ERROR);
@@ -190,7 +240,8 @@ gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, guchar
 
 gboolean gems_security_init_sha(EVP_MD_CTX* md)
 {
-	EVP_MD_CTX_init(md);
+	//EVP_MD_CTX_init(md); Not needed since md is created with EVP_MD_CTX_Create
+	if(md == NULL) return FALSE;
 	if(EVP_DigestInit_ex(md, EVP_sha256(), NULL) == 0)
 	{
 		gchar* logmsg = g_strdup_printf("gems_security_init_sha() : Cannot init sha digest.");
@@ -203,12 +254,12 @@ gboolean gems_security_init_sha(EVP_MD_CTX* md)
 
 guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 {
-	EVP_MD_CTX* md = NULL;
 	guint hash_length = 0;
 	guchar* hash = NULL;
 	gchar* logmsg = NULL;
+	gems_security_context* security = gems_get_security_contexts();
 	
-	if(gems_get_security_contexts() == NULL)
+	if(security == NULL)
 	{
 		logmsg = g_strdup_printf("gems_security_calculate_hash() : Cannot calculate hash, security contexts not initialized.");
 		cem_add_to_log(logmsg,J_LOG_ERROR);
@@ -216,7 +267,7 @@ guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 		return NULL;
 	}
 	
-	if((md = gems_get_security_contexts()->digest) == NULL)
+	if(security->digest == NULL)
 	{
 		logmsg = g_strdup_printf("gems_security_calculate_hash() : Cannot calculate hash, hash context not initialized.");
 		cem_add_to_log(logmsg,J_LOG_ERROR);
@@ -228,7 +279,7 @@ guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 	memset(hash,0,EVP_MAX_MD_SIZE);
 	
 	// Failure, cannot initialize
-	if(EVP_DigestInit_ex(md, EVP_sha256(), NULL) == 0) 
+	if(EVP_DigestInit_ex(security->digest, EVP_sha256(), NULL) == 0) 
 	{
 		logmsg = g_strdup_printf("gems_security_calculate_hash() : Cannot calculate hash, cannot initialize digest.");
 		cem_add_to_log(logmsg,J_LOG_ERROR);
@@ -236,8 +287,8 @@ guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 		return NULL;
 	}
 	
-	EVP_DigestUpdate(md,data,strlen((gchar*)data));
-	EVP_DigestFinal_ex(md,hash,&hash_length);
+	EVP_DigestUpdate(security->digest,data,strlen((gchar*)data));
+	EVP_DigestFinal_ex(security->digest,hash,&hash_length);
 	*data_length = hash_length;
 	
 	return hash;
@@ -276,7 +327,7 @@ guchar* gems_security_encrypt_data(guchar* profile_data, guint* data_length)
 	encrypted_profile = (guchar*)g_malloc(sizeof(guchar*)*enc_length);
 	memset(encrypted_profile,0,enc_length);
 	
-	//EVP_EncryptInit_ex(enc,NULL,NULL,NULL,NULL);
+	EVP_EncryptInit_ex(enc,NULL,NULL,NULL,NULL);
 	EVP_EncryptUpdate(enc, encrypted_profile, &enc_length, profile_data, *data_length);
 	EVP_EncryptFinal_ex(enc, encrypted_profile + enc_length, &final_length);
 	
@@ -313,7 +364,7 @@ guchar* gems_security_decrypt_data(guchar* profile_data, guint* data_length)
 	decrypted_profile = (guchar*)g_malloc(sizeof(guchar*)*dec_length);
 	memset(decrypted_profile,0,dec_length);
 	
-	//EVP_DecryptInit_ex(dec,NULL,NULL,NULL,NULL);
+	EVP_DecryptInit_ex(dec,NULL,NULL,NULL,NULL);
 	EVP_DecryptUpdate(dec, decrypted_profile, &dec_length, profile_data, *data_length);
 	EVP_DecryptFinal_ex(dec, decrypted_profile + dec_length, &final_length);
 	
